@@ -4,6 +4,7 @@
 #pragma once
 
 #include "interface/namespace.h"
+#include <qpair.h>
 
 #include <QWidget>
 
@@ -17,8 +18,13 @@ public:
     bool isSelected();
     void setSelected(bool selected);
     static const int EXTRA = 2; //2px extra space to avoid line cutted off
+                                //
+    QColor color() const { return m_color; }
     void setColor(const QColor &color);
 
+    QPair<QString, QString> activeColors() const { return m_activeColors; }
+    void setActiveColors(const QPair<QString, QString> &colors);
+
 Q_SIGNALS:
     void clicked();
 
@@ -30,4 +36,5 @@ protected:
 private:
     bool m_isSelected;
     QColor m_color;
+    QPair<QString, QString> m_activeColors;
 };
