@@ -10,6 +10,12 @@
 #include <QDBusInterface>
 #include <QDBusArgument>
 #include <QDBusReply>
+#include <QDBusConnectionInterface>
+#include <QLoggingCategory>
+
+namespace {
+    Q_LOGGING_CATEGORY(dcCommonLog, "dcc.commoninfo")
+}
 
 const QString &GrubService = QStringLiteral("org.deepin.dde.Grub2");
 const QString &GrubPath = QStringLiteral("/org/deepin/dde/Grub2");
@@ -41,16 +47,35 @@ const QString &SyncHelperService = QStringLiteral("com.deepin.sync.Helper");
 const QString &SyncHelperPath = QStringLiteral("/com/deepin/sync/Helper");
 const QString &SyncHelperInterface = QStringLiteral("com.deepin.sync.Helper");
 
+static const QString &ACLHelperService = QStringLiteral("com.deepin.daemon.ACL");
+static const QString &ACLHelperPath = QStringLiteral("/com/uos/usec/DeveloperMode");
+static const QString &ACLHelperInterface = QStringLiteral("com.uos.usec.DeveloperMode");
+
+// 判断是否可以使用ACL服务来处理开发者模式
+static bool isACLActivatable()
+{
+    const bool enableACL = qEnvironmentVariableIsSet("DCC_ACL_ENABLED");
+    if (enableACL)
+        return true;
+
+    if (!QDBusConnection::systemBus().interface()->isServiceRegistered(ACLHelperService))
+        return false;
+
+    QDBusInterface interface(ACLHelperService, ACLHelperPath, ACLHelperInterface, QDBusConnection::systemBus());
+    return interface.isValid();
+}
+
 CommonInfoProxy::CommonInfoProxy(QObject *parent)
     : QObject(parent)
     , m_grubInter(new DDBusInterface(GrubService, GrubPath, GrubInterface, QDBusConnection::systemBus(), this))
     , m_grubThemeInter(new DDBusInterface(GrubService, GrubThemePath, GrubThemeInterface, QDBusConnection::systemBus(), this))
     , m_grubEditAuthInter(new DDBusInterface(GrubService, GrubEditAuthPath, GrubEditAuthInterface, QDBusConnection::systemBus(), this))
-    , m_deepinIdInter(new DDBusInterface(DeepinIdService, DeepinIdPath, DeepinIdInterface, QDBusConnection::sessionBus(), this))
+    , m_deepinIdInter(nullptr)
     , m_licenseInter(new DDBusInterface(LicenseService, LicensePath, LicenseInterface, QDBusConnection::systemBus(), this))
     , m_userexperienceInter(new DDBusInterface(UserexperienceService, UserexperiencePath, UserexperienceInterface, QDBusConnection::sessionBus(), this))
     , m_grubScaleInter(new DDBusInterface(PlyMouthScaleService, PlyMouthScalePath, PlyMouthScaleInterface, QDBusConnection::systemBus(), this))
-    , m_syncHelperInter(new DDBusInterface(SyncHelperService, SyncHelperPath, SyncHelperInterface, QDBusConnection::systemBus(), this))
+    , m_syncHelperInter(nullptr)
+    , m_aclInter(nullptr)
 {
     // in this function, it will wait for 50 seconds finall return
     m_grubScaleInter->setTimeout(50000);
@@ -63,27 +88,89 @@ CommonInfoProxy::CommonInfoProxy(QObject *parent)
         this,
         SIGNAL(BackgroundChanged())
     );
-    QDBusConnection::sessionBus().connect(DeepinIdService, DeepinIdPath, DeepinIdInterface, "Error", this, SIGNAL(DeepinIdError(const int, const QString &)));
+
+    QDBusConnection::systemBus().connect(
+        LicenseService,
+        LicensePath,
+        LicenseInterface,
+        "LicenseStateChange",
+        this, SLOT(onLicenseStateChanged()));
+
+    m_isACLController =  isACLActivatable();
+    if (m_isACLController) {
+        qInfo(dcCommonLog) << "DeveloperMode uses ACL service to work.";
+    } else {
+        qInfo(dcCommonLog) << "ACL is unActivatable, DeveloperMode uses deepinId service to work.";
+    }
+    if (m_isACLController) {
+        m_aclInter = new DDBusInterface(ACLHelperService, ACLHelperPath, ACLHelperInterface, QDBusConnection::systemBus(), this);
+        if (!m_aclInter->isValid()) {
+            qWarning(dcCommonLog) << "ACL is invalid, error msg:" << m_aclInter->lastError();
+        }
+        QDBusConnection::systemBus().connect(ACLHelperService, ACLHelperPath, ACLHelperInterface, "NotifyDeveloperMode",
+                                             this,
+                                             SIGNAL(DeveloperModeChanged(bool)));
+        QDBusConnection::systemBus().connect(ACLHelperService, ACLHelperPath, ACLHelperInterface, "NotifyDeveloperMode",
+                                             this,
+                                             SIGNAL(DeviceUnlockedChanged(bool)));
+        QDBusConnection::systemBus().connect(ACLHelperService, ACLHelperPath, ACLHelperInterface, "NotifyDeveloperModeError",
+                                             this,
+                                             SLOT(onACLError(quint32)));
+    } else {
+        m_syncHelperInter = new DDBusInterface(SyncHelperService, SyncHelperPath, SyncHelperInterface, QDBusConnection::systemBus(), this);
+        m_deepinIdInter = new DDBusInterface(DeepinIdService, DeepinIdPath, DeepinIdInterface, QDBusConnection::sessionBus(), this);
+        QDBusConnection::sessionBus().connect(DeepinIdService, DeepinIdPath, DeepinIdInterface, "Error", this, SIGNAL(onDeepinIdError(const int, const QString &)));
+    }
 }
 
 bool CommonInfoProxy::IsLogin()
 {
-    return qvariant_cast<bool>(m_deepinIdInter->property("IsLogin"));
+    if (m_isACLController) {
+        qWarning(dcCommonLog) << "Don't need to check isLogin deepinId when using ACL service.";
+        return false;
+    } else {
+        return qvariant_cast<bool>(m_deepinIdInter->property("IsLogin"));
+    }
 }
 
 bool CommonInfoProxy::DeviceUnlocked()
 {
-    return qvariant_cast<bool>(m_deepinIdInter->property("DeviceUnlocked"));
+    if (m_isACLController) {
+        QDBusReply<bool> reply = m_aclInter->call("GetDeveloperModeStatus");
+        if (reply.isValid()) {
+            return reply.value();
+        }
+        qWarning(dcCommonLog) << "Failed to GetDeveloperModeStatus";
+        return false;
+    } else {
+        return qvariant_cast<bool>(m_deepinIdInter->property("DeviceUnlocked"));
+    }
 }
 
 void CommonInfoProxy::UnlockDevice()
 {
-    m_deepinIdInter->asyncCall("UnlockDevice");
+    if (m_isACLController) {
+        QDBusPendingCall call = m_aclInter->asyncCall("AsyncEnableDeveloperModeCompatible");
+        QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(call, this);
+        connect(watcher, &QDBusPendingCallWatcher::finished, this, [this](QDBusPendingCallWatcher *w) {
+            if (w->isError()) {
+                qWarning(dcCommonLog) << "EnableDeveloperModeCompatible DBus call failed:" << w->error().message();
+                Q_EMIT developModeError("1001");
+            }
+            w->deleteLater();
+        });
+    } else {
+        m_deepinIdInter->asyncCall("UnlockDevice");
+    }
 }
 
 void CommonInfoProxy::Login()
 {
-    m_deepinIdInter->asyncCall("Login");
+    if (m_isACLController) {
+        qWarning(dcCommonLog) << "Don't need login deepinId when using ACL service.";
+    } else {
+        m_deepinIdInter->asyncCall("Login");
+    }
 }
 
 QStringList CommonInfoProxy::GetSimpleEntryTitles()
@@ -174,7 +261,11 @@ QDBusPendingCall CommonInfoProxy::SetScalePlymouth(int scale)
 
 bool CommonInfoProxy::DeveloperMode()
 {
-    return qvariant_cast<bool>(m_syncHelperInter->property("DeveloperMode"));
+    if (m_isACLController) {
+        return DeviceUnlocked();
+    } else {
+        return qvariant_cast<bool>(m_syncHelperInter->property("DeveloperMode"));
+    }
 }
 
 QString CommonInfoProxy::Background()
@@ -217,3 +308,32 @@ void CommonInfoProxy::Notify(const QString &inAppName, const uint replacesId, co
 {
     Dtk::Core::DUtil::DNotifySender(summary).appName(inAppName).replaceId(replacesId).appIcon(appIcon).appBody(body).actions(actions).hints(hints).timeOut(expireTimeout).call();
 }
+
+bool CommonInfoProxy::isACLController() const
+{
+    return m_isACLController;
+}
+
+void CommonInfoProxy::onDeepinIdError(const int code, const QString &msg)
+{
+    Q_UNUSED(code);
+
+    QString msgCode = msg;
+    msgCode = msgCode.split(":").at(0);
+
+    Q_EMIT developModeError(msgCode);
+}
+
+void CommonInfoProxy::onACLError(quint32 exitCode)
+{
+    if (exitCode != 256) {
+        qWarning(dcCommonLog) << "AsyncEnableDeveloperModeCompatible DBus call exitCode:" << exitCode;
+        Q_EMIT developModeError("1001");
+    }
+}
+
+void CommonInfoProxy::onLicenseStateChanged()
+{
+    const auto state = AuthorizationState();
+    Q_EMIT AuthorizationStateChanged(state);
+}
