@@ -124,7 +124,7 @@ static inline QString escapSpace(const QString &space)
 static inline QString normalizeSpace(const QString &value)
 {
     QString ret = " ";
-    QStringList numberKeepList{ QString("."), QString(","), QString("'"), QString("٬")};
+    QStringList numberKeepList{ QString("."), QString(","), QString("'"), QString("٬"), QString("’"), QString("ወ"), QString("،")};
     if (numberKeepList.contains(value)) {
         ret = value;
     } else {
@@ -172,6 +172,7 @@ DatetimeModel::DatetimeModel(QObject *parent)
     : QObject(parent)
     , m_ntp(true)
     , m_bUse24HourType(true)
+    , m_previousServerAddress("")
     , m_work(new DatetimeWorker(this, this))
 {
     connect(this, &DatetimeModel::ntpChanged, m_work, &DatetimeWorker::setNTP);
@@ -235,6 +236,16 @@ DatetimeModel::DatetimeModel(QObject *parent)
     qmlRegisterType<dccV25::ZoneInfoModel>("ZoneInfoModel", 1, 0, "ZoneInfoModel");
 }
 
+DatetimeModel::~DatetimeModel()
+{
+    bool isCustomizeMode = !m_NtpServerList.contains(m_strNtpServerAddress);
+    if (isCustomizeMode && m_strNtpServerAddress.isEmpty() && !m_previousServerAddress.isEmpty()) {
+        if (m_work) {
+            m_work->setNtpServer(m_previousServerAddress);
+        }
+    }
+}
+
 void DatetimeModel::setNTP(bool ntp)
 {
     if (m_ntp != ntp) {
@@ -519,28 +530,18 @@ void DatetimeModel::setRegion(const QString &region)
 
     m_regionName = region;
     auto reg = m_langRegionsCache.value(region, region);
-    QLocale locale(QLocale::C);
     for (const auto &tmplocale : m_regions) {
         if (tmplocale.territoryToCode(tmplocale.territory()) == reg) {
-            if (m_work->genLocale(tmplocale.name())) {
-                locale = tmplocale;
-                qDebug() << "set locale success:" << locale.name();
-                break;
-            }
-            if (locale.language() == QLocale::C) {
-                locale = tmplocale;
-            }
-        }
-    }
-    if (locale.language() != QLocale::C) {
-        qDebug() << "set locale:" << locale.name();
-        QString country = locale.territoryToString(locale.territory());
-        QString language = QLocale::languageToString(locale.language());
-        QString langCountry = QString("%1:%2").arg(language).arg(country);
-        m_work->setConfigValue(country_key, country);
+            qDebug() << "set locale:" << tmplocale.name();
+            QString country = tmplocale.territoryToString(tmplocale.territory());
+            QString language = QLocale::languageToString(tmplocale.language());
+            QString langCountry = QString("%1:%2").arg(language).arg(country);
+            m_work->setConfigValue(country_key, country);
 
-        Q_EMIT regionChanged(region);
-        Q_EMIT currentRegionIndexChanged(currentRegionIndex());
+            Q_EMIT regionChanged(region);
+            Q_EMIT currentRegionIndexChanged(currentRegionIndex());
+            break;
+        }
     }
 }
 
@@ -578,6 +579,8 @@ void DatetimeModel::setCurrentLocaleAndLangRegion(const QString &localeName, con
     RegionFormat regionFormat = RegionProxy::regionFormat(locale);
     // case FirstDayOfWeek:
     m_work->setConfigValue(firstDayOfWeek_key, regionFormat.firstDayOfWeekFormat);
+    m_work->setWeekStartDayFormat(regionFormat.firstDayOfWeekFormat < 1 ? 0 : regionFormat.firstDayOfWeekFormat - 1);
+    setFirstDayOfWeek(regionFormat.firstDayOfWeekFormat);
     // case ShortDate:
     m_work->setConfigValue(shortDateFormat_key, regionFormat.shortDateFormat);
     // case LongDate:
@@ -862,6 +865,14 @@ QString DatetimeModel::currentTime() const
     return locale.toString(QTime::currentTime(), timeFormat);
 }
 
+QString DatetimeModel::getCustomNtpServer() const
+{
+    if (m_work) {
+        return m_work->getCustomNtpServer();
+    }
+    return QString();
+}
+
 int DatetimeModel::currentLanguageAndRegionIndex()
 {
     return m_regions.keys().indexOf(m_langCountry);
@@ -961,6 +972,14 @@ void DatetimeModel::setNtpServerAddress(const QString &ntpServer)
     }
 }
 
+void DatetimeModel::setPreviousServerAddress(const QString &address)
+{
+    if (m_previousServerAddress != address) {
+        m_previousServerAddress = address;
+        Q_EMIT previousServerAddressChanged(address);
+    }
+}
+
 void DatetimeModel::setNTPServerList(const QStringList &list)
 {
     if (m_NtpServerList != list) {
