@@ -9,18 +9,26 @@
 #include <QtConcurrent>
 #include <QFutureWatcher>
 #include <QLoggingCategory>
+#include <QDBusPendingCallWatcher>
+#include <QDBusPendingReply>
 
 #include <dconfig.h>
 #include <qvariant.h>
 
 Q_LOGGING_CATEGORY(DdcDateTimeWorkder, "dcc-datetime-worker")
 
+static const QStringList customTimeZoneList = {
+    "Asia/Chengdu", "Asia/Beijing", "Asia/Nanjing", "Asia/Wuhan", "Asia/Xian", "Asia/Urumqi"
+};
+
 DatetimeWorker::DatetimeWorker(DatetimeModel *model, QObject *parent)
     : QObject(parent)
     , m_model(model)
     , m_timedateInter(new DatetimeDBusProxy(this))
     , m_regionInter(new RegionProxy(this))
     , m_config(DTK_CORE_NAMESPACE::DConfig::createGeneric("org.deepin.region-format", QString(), this))
+    , m_datetimeConfig(DTK_CORE_NAMESPACE::DConfig::create("org.deepin.dde.control-center", "org.deepin.dde.control-center.datetime", QString(), this))
+    , m_daemonTimedateConfig(DTK_CORE_NAMESPACE::DConfig::create("org.deepin.dde.daemon", "org.deepin.dde.daemon.timedate", QString(), this))
 {
     QMetaObject::invokeMethod(this, "activate", Qt::QueuedConnection);
 #ifndef DCC_DISABLE_TIMEZONE
@@ -45,6 +53,8 @@ DatetimeWorker::DatetimeWorker(DatetimeModel *model, QObject *parent)
                 break;
             }
         }
+
+        Q_EMIT m_model->currentFormatChanged(DatetimeModel::LongTime);
     });
 
     connect(m_timedateInter, &DatetimeDBusProxy::NTPServerChanged, m_model, &DatetimeModel::setNtpServerAddress);
@@ -152,7 +162,27 @@ void DatetimeWorker::set24HourType(bool state)
 #ifndef DCC_DISABLE_TIMEZONE
 void DatetimeWorker::setTimezone(const QString &timezone)
 {
-    m_timedateInter->SetTimezone(timezone);
+    QString currentTimezone = m_timedateInter->timezone();
+    bool isNeedUpdateProp = (timezone == "Asia/Shanghai" && customTimeZoneList.contains(currentTimezone)) ||
+                            customTimeZoneList.contains(timezone);
+
+    QDBusPendingCall call = m_timedateInter->SetTimezone(timezone, tr("Authentication is required to set the system timezone"));
+    
+    QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(call, this);
+    connect(watcher, &QDBusPendingCallWatcher::finished, this, [this, timezone, isNeedUpdateProp](QDBusPendingCallWatcher *w) {
+        QDBusPendingReply<> reply = *w;
+        if (reply.isError()) {
+            qCWarning(DdcDateTimeWorkder) << "SetTimezone failed:" << reply.error().message();
+            return;
+        }
+
+        if (isNeedUpdateProp && m_daemonTimedateConfig && m_daemonTimedateConfig->isValid()) {
+            m_daemonTimedateConfig->setValue("timeZone", timezone);
+        }
+        m_timedateInter->AddUserTimezone(timezone);
+        Q_EMIT m_timedateInter->TimezoneChanged(timezone);
+        w->deleteLater();
+    });
 }
 
 void DatetimeWorker::removeUserTimeZone(const QString &zone)
@@ -171,9 +201,31 @@ void DatetimeWorker::setNtpServer(QString server)
 
     if (server == m_timedateInter->nTPServer())
         return;
+
+    bool isCustomServer = !m_model->ntpServerList().contains(server);
+    if (isCustomServer) {
+        if (m_datetimeConfig) {
+            if (m_datetimeConfig->isValid()) {
+                QString previousCustom = m_datetimeConfig->value("customNtpServer").toString();
+                m_datetimeConfig->setValue("customNtpServer", server);
+            } else {
+                qWarning() << "Cannot save custom NTP server: dconfig is not valid!";
+            }
+        } else {
+            qWarning() << "Cannot save custom NTP server: dconfig is null!";
+        }
+    }
     m_timedateInter->SetNTPServer(server, tr("Authentication is required to change NTP server"), this, SLOT(SetNTPServerFinished()), SLOT(SetNTPServerError()));
 }
 
+QString DatetimeWorker::getCustomNtpServer()
+{
+    if (m_datetimeConfig && m_datetimeConfig->isValid()) {
+        return m_datetimeConfig->value("customNtpServer").toString();
+    }
+    return QString();
+}
+
 int DatetimeWorker::weekdayFormat()
 {
     return m_timedateInter->weekdayFormat();
