@@ -16,53 +16,53 @@
 #include <DPinyin>
 
 QStringList systemFilter = {"terminal",
-                            "terminal-quake",
-                            "global-search",
+                            "terminalQuake",
+                            "globalSearch",
                             "screenshot",
-                            "screenshot-delayed",
-                            "screenshot-fullscreen",
-                            "screenshot-window",
-                            "screenshot-scroll",
-                            "screenshot-ocr",
-                            "deepin-screen-recorder",
-                            "switch-group",
-                            "switch-group-backward",
-                            "preview-workspace",
+                            "screenshotDelayed",
+                            "screenshotFullscreen",
+                            "screenshotWindow",
+                            "screenshotScroll",
+                            "screenshotOcr",
+                            "deepinScreenRecorder",
+                            "switchGroup",
+                            "switchGroupBackward",
+                            "previewWorkspace",
                             "launcher",
-                            "switch-applications",
-                            "switch-applications-backward",
-                            "show-desktop",
-                            "file-manager",
-                            "lock-screen",
+                            "switchApplications",
+                            "switchApplicationsBackward",
+                            "showDesktop",
+                            "fileManager",
+                            "lockScreen",
                             "logout",
-                            "wm-switcher",
-                            "system-monitor",
-                            "color-picker",
+                            "wmSwitcher",
+                            "systemMonitor",
+                            "colorPicker",
                             "clipboard",
-                            "switch-monitors"
+                            "switchMonitors"
 };
 
 const QStringList &windowFilter = {"maximize",
                                    "unmaximize",
                                    "minimize",
-                                   "begin-move",
-                                   "begin-resize",
+                                   "beginMove",
+                                   "beginResize",
                                    "close",
-                                   "toggle-to-left",
-                                   "toggle-to-right"
+                                   "toggleToLeft",
+                                   "toggleToRight"
 };
 
-const QStringList &workspaceFilter = {"switch-to-workspace-left",
-                                      "switch-to-workspace-right",
-                                      "move-to-workspace-left",
-                                      "move-to-workspace-right"};
+const QStringList &workspaceFilter = {"switchToWorkspaceLeft",
+                                      "switchToWorkspaceRight",
+                                      "moveToWorkspaceLeft",
+                                      "moveToWorkspaceRight"};
 
-const QStringList &assistiveToolsFilter = {"text-to-speech",
-                                           "speech-to-text",
+const QStringList &assistiveToolsFilter = {"textToSpeech",
+                                           "speechToText",
                                            "translation",
-                                            "view-zoom-in",
-                                            "view-zoom-out",
-                                            "view-actual-size"};
+                                            "viewZoomIn",
+                                            "viewZoomOut",
+                                            "viewActualSize"};
 
 // from dquickrectangle_p.h
 #define NoneCorner 0x0
@@ -76,6 +76,8 @@ const QStringList &assistiveToolsFilter = {"text-to-speech",
 #define RightCorner TopRightCorner| BottomRightCorner
 #define AllCorner TopCorner | BottomCorner
 
+static const QString FieldSeparator = QString(QChar(0x1F));
+
 static const QMap<QString, QString> &DisplaykeyMap = { {"exclam", "!"}, {"at", "@"}, {"numbersign", "#"}, {"dollar", "$"}, {"percent", "%"},
     {"asciicircum", "^"}, {"ampersand", "&"}, {"asterisk", "*"}, {"parenleft", "("},
     {"parenright", ")"}, {"underscore", "_"}, {"plus", "+"}, {"braceleft", "{"}, {"braceright", "}"},
@@ -89,7 +91,7 @@ static const QMap<QString, QString> &DisplaykeyMap = { {"exclam", "!"}, {"at", "
 static QString toPinyin(const QString &name)
 {
     DCORE_USE_NAMESPACE
-    return pinyin(name, TS_NoneTone).join("_") + "_" + firstLetters(name).join("_");
+    return pinyin(name, TS_NoneTone).join(FieldSeparator) + FieldSeparator + firstLetters(name).join(FieldSeparator);
 }
 
 using namespace dccV25;
@@ -220,6 +222,9 @@ void ShortcutModel::onParseInfo(const QString &info)
     m_workspaceInfos.clear();
     m_assistiveToolsInfos.clear();
     m_customInfos.clear();
+    
+    // 清理系统快捷键名称缓存，因为数据即将更新
+    invalidateSystemShortcutNamesCache();
 
     QJsonArray array = QJsonDocument::fromJson(info.toStdString().c_str()).array();
 
@@ -372,6 +377,10 @@ void ShortcutModel::onWindowSwitchChanged(bool value)
                 m_systemInfos.removeOne(m_windowSwitchStateInfos.at(i));
             }
         }
+        
+        // 系统快捷键列表发生变化，清理缓存
+        invalidateSystemShortcutNamesCache();
+        
         Q_EMIT windowSwitchChanged(m_windowSwitchState);
     }
 }
@@ -519,6 +528,52 @@ bool ShortcutModel::searchResultContains(const QString &id)
     return res != m_infos.end();
 }
 
+QStringList ShortcutModel::getSystemShortcutNames() const
+{
+    QStringList names;
+    
+    // 合并所有系统相关的快捷键列表
+    QList<QList<ShortcutInfo *>> systemLists = {
+        m_systemInfos,
+        m_windowInfos, 
+        m_workspaceInfos,
+        m_assistiveToolsInfos
+    };
+    
+    for (const auto &list : systemLists) {
+        for (const auto *info : list) {
+            if (info && !info->name.trimmed().isEmpty()) {
+                names.append(info->name.trimmed());
+            }
+        }
+    }
+    
+    return names;
+}
+
+bool ShortcutModel::containsSystemShortcutName(const QString &name) const
+{
+    // 处理边界情况
+    if (name.trimmed().isEmpty()) {
+        return false;
+    }
+    
+    // 使用成员变量缓存提高查找效率
+    if (m_systemNamesCache.isEmpty()) {
+        // 构建缓存
+        const QStringList systemNames = getSystemShortcutNames();
+        m_systemNamesCache = QSet<QString>(systemNames.begin(), systemNames.end());
+    }
+    
+    return m_systemNamesCache.contains(name.trimmed());
+}
+
+void ShortcutModel::invalidateSystemShortcutNamesCache() const
+{
+    // 清空缓存，强制下次访问时重新构建
+    m_systemNamesCache.clear();
+}
+
 ShortcutListModel::ShortcutListModel(QObject *parent)
     : QAbstractListModel(parent)
 {
@@ -567,7 +622,7 @@ QVariant ShortcutListModel::data(const QModelIndex &index, int role) const
     case Qt::DisplayRole:
         return info->name;
     case SearchedTextRole:
-        return info->name + info->pinyin + "_" + displayKeys.join("_");
+        return info->name + info->pinyin + FieldSeparator + displayKeys.join(FieldSeparator);
     case IdRole:
         return info->id;
     case TypeRole:
