@@ -18,6 +18,7 @@ public Q_SLOTS:
     void setWindowEffect(int value) override;
     void setMovedWindowOpacity(bool value) override;
     void setMiniEffect(int effect) override;
+    virtual void setWallpaperForMonitor(const QString &screen, const QString &url, bool isDark, PersonalizationExport::WallpaperSetOption option) override;
     void setBackgroundForMonitor(const QString &screenName, const QString &url, bool isDark) override;
     void setLockBackForMonitor(const QString &screenName, const QString &url, bool isDark) override;
 
@@ -26,6 +27,7 @@ private Q_SLOTS:
 
 private:
     void onKWinConfigChanged(const QString &key);
+    void onTitleHeightChanged();
 
 private:
     Dtk::Core::DConfig *m_kwinTitleBarConfig = nullptr;
