@@ -195,6 +195,7 @@ public:
 
     inline int shutdownRepetition() const { return m_shutdownRepetition; }
     void setShutdownRepetition(int repetition);
+    Q_INVOKABLE void refreshShutdownRepetition() { Q_EMIT shutdownRepetitionChanged(m_shutdownRepetition); }
 
     inline int weekBegins() const { return m_weekBegins; }
     void setWeekBegins(int value);
@@ -228,7 +229,7 @@ public:
 
 Q_SIGNALS:
     void sleepLockChanged(const bool sleepLock);
-    void canSleepChanged(const bool canSleep);
+    void canSuspendChanged(const bool canSuspend);
     void screenBlackLockChanged(const bool screenBlackLock);
     void lidPresentChanged(const bool lidPresent);
     void sleepOnLidOnPowerCloseChanged(const bool sleepOnLidClose);
